@@ -9,7 +9,7 @@ style.background = { common.color "#141b1e" }
 style.background2 = { common.color "#1e2528" }
 style.background3 = { common.color "#2d3437" }
 style.text = { common.color "#dadada" }
-style.caret = { common.color "#dadadda" }
+style.caret = { common.color "#dadada" }
 style.accent = { common.color "#67b0e8" }
 style.dim = { common.color "#bdc3c2" }
 style.divider = { common.color "#232a2d" }
@@ -25,7 +25,7 @@ style.syntax["symbol"] = { common.color "#b3b9b8" }
 style.syntax["comment"] = { common.color "#404749" }
 style.syntax["keyword"] = { common.color "#67b0e8" }
 style.syntax["keyword2"] = { common.color "#6cbfbf" }
-style.syntax["number"] = { common.color "dadada" }
+style.syntax["number"] = { common.color "#dadada" }
 style.syntax["literal"] = { common.color "#e5c76b" }
 style.syntax["string"] = { common.color "#75cf72" }
 style.syntax["operator"] = { common.color "#bab3e5" }
