@@ -823,6 +823,9 @@ map_new_syntax_colors = function(clear_new)
     ["annotation.type"]       = { alt = "keyword2", dec=30 },
     ["annotation.operator"]   = { alt = "operator", dec=30 },
     ["annotation.function"]   = { alt = "function", dec=30 },
+    ["annotation.number"]     = { alt = "number",   dec=30 },
+    ["annotation.keyword2"]   = { alt = "keyword2", dec=30 },
+    ["annotation.literal"]    = { alt = "literal",  dec=30 },
     ["attribute"]             = { alt = "keyword",  dec=30 },
     -- Keywords like: true or false
     ["boolean"]               = { alt = "literal"   },
@@ -1230,26 +1233,21 @@ end
 ---This function rescales the interface to the system default scale
 ---by incrementing or decrementing current user scale.
 local function update_scale()
-  if SCALE == DEFAULT_SCALE or config.plugins.scale.autodetect then
-    local new_scale = system.get_scale(core.window)
-    if DEFAULT_SCALE ~= new_scale then
-      if new_scale == SCALE then
-        DEFAULT_SCALE = new_scale
-        return
-      end
-      local target, target_code
-      if new_scale > DEFAULT_SCALE then
-        target = scale.get() + (new_scale - DEFAULT_SCALE)
-        target_code = scale.get_code() + (new_scale - DEFAULT_SCALE)
-      else
-        target = scale.get() - (DEFAULT_SCALE - new_scale)
-        target_code = scale.get_code() - (DEFAULT_SCALE - new_scale)
-      end
-      -- do not scale smaller than new_scale
-      scale.set(target < new_scale and new_scale or target)
-      scale.set_code(target_code < new_scale and new_scale or target_code)
-      DEFAULT_SCALE = new_scale
+  local new_scale, prev_default = system.get_scale(core.window), DEFAULT_SCALE
+  DEFAULT_SCALE = new_scale
+  if SCALE == prev_default or config.plugins.scale.autodetect then
+    if new_scale == SCALE then return end
+    local target, target_code
+    if new_scale > prev_default then
+      target = scale.get() + (new_scale - prev_default)
+      target_code = scale.get_code() + (new_scale - prev_default)
+    else
+      target = scale.get() - (prev_default - new_scale)
+      target_code = scale.get_code() - (prev_default - new_scale)
     end
+    -- do not scale smaller than new_scale
+    scale.set(target < new_scale and new_scale or target)
+    scale.set_code(target_code < new_scale and new_scale or target_code)
   end
 end
 
@@ -1539,6 +1537,28 @@ local run_threads = coroutine.wrap(function()
 end)
 
 
+-- Override default collectgarbage function to prevent users from performing
+-- a system stalling garbage collection, instead a new forcecollect option
+-- can be used.
+local collectgarbage_lua = collectgarbage
+
+---This function is a generic interface to the garbage collector.
+---It performs different functions according to its first argument, `opt`.
+---@param opt? gcoptions | "forcecollect"
+---@param ... any
+---@return any
+function collectgarbage(opt, ...)
+  local ret
+  if not opt or opt == "collect" then
+    ret = collectgarbage_lua("step", 10*1024)
+  elseif opt == "forcecollect" then
+    ret = collectgarbage_lua("collect")
+  else
+    ret = collectgarbage_lua(opt, ...)
+  end
+  return ret
+end
+
 function core.run()
   scale = require "plugins.scale"
   local next_step
@@ -1599,7 +1619,7 @@ function core.run()
             local cursor_time_to_wake = dt + 1 / core.fps
             next_step = now + cursor_time_to_wake
           end
-          local b = burst_events > now and rendering_speed or 1
+          local b = (config.lower_input_latency and burst_events > now) and rendering_speed or 1
           if system.wait_event(math.min(next_step - now, time_to_wake, b)) then
             next_step = nil
             -- burst event processing speed to reduce input lag
