@@ -99,11 +99,11 @@ local StatusViewItem = Object:extend()
 ---follows it.
 ---@field separator? core.statusview.item.separator
 
----Flag to tell the item should me aligned on left side of status bar.
+---Flag to tell the item should be aligned on left side of status bar.
 ---@type integer
 StatusViewItem.LEFT = 1
 
----Flag to tell the item should me aligned on right side of status bar.
+---Flag to tell the item should be aligned on right side of status bar.
 ---@type integer
 StatusViewItem.RIGHT = 2
 
@@ -168,7 +168,7 @@ end
 function StatusView:new()
   StatusView.super.new(self)
   self.message_timeout = 0
-  self.message = {}
+  self.message = nil
   self.tooltip_mode = false
   self.tooltip = {}
   self.items = {}
@@ -203,10 +203,29 @@ function StatusView:register_docview_items()
     alignment = StatusView.Item.LEFT,
     get_item = function()
       local dv = core.active_view
+      local filename
+      if #core.projects > 1 and dv.doc.abs_filename then
+        local project, is_open, belongs = core.current_project(
+          dv.doc.abs_filename
+        )
+        if project and is_open and belongs then
+          filename = {
+            style.accent,
+            common.basename(project.path),
+            style.text,
+            PATHSEP .. common.relative_path(project.path, dv.doc.abs_filename)
+          }
+        end
+      end
+      if not filename then
+        filename = {
+          dv.doc.filename and style.text or style.dim,
+          common.home_encode(dv.doc:get_name())
+        }
+      end
       return {
         dv.doc:is_dirty() and style.accent or style.text, style.icon_font, "f",
-        style.dim, style.font, self.separator2, style.text,
-        dv.doc.filename and style.text or style.dim, common.home_encode(dv.doc:get_name())
+        style.dim, style.font, self.separator2, table.unpack(filename)
       }
     end
   })
@@ -336,9 +355,10 @@ function StatusView:register_docview_items()
     name = "doc:encoding",
     alignment = StatusView.Item.RIGHT,
     get_item = function()
-      local dv = core.active_view
+      local dv, bom = core.active_view, ""
+      if dv.doc.bom then bom = " (BOM)" end
       return {
-        style.text, dv.doc.encoding or "none"
+        style.text, (dv.doc.encoding or "none"), bom
       }
     end,
     command = function(button)
@@ -589,8 +609,9 @@ end
 function StatusView:show_message(icon, icon_color, text)
   if not self.visible or self.hide_messages then return end
   self.message = {
-    icon_color, style.icon_font, icon,
-    style.dim, style.font, StatusView.separator2, style.text, text
+    icon = icon,
+    icon_color = icon_color,
+    text = text
   }
   self.message_timeout = system.get_time() + config.message_timeout
 end
@@ -1073,7 +1094,7 @@ function StatusView:on_mouse_moved(x, y, dx, dy)
     return
   end
 
-  if y < self.position.y or system.get_time() <= self.message_timeout then
+  if y < self.position.y or self.message then
     self.cursor = "arrow"
     self.hovered_item = {}
     return
@@ -1158,7 +1179,7 @@ function StatusView:update()
     self.size.y = height
   end
 
-  if system.get_time() < self.message_timeout then
+  if self.message and system.get_time() < self.message_timeout then
     self.scroll.to.y = self.size.y
   else
     self.scroll.to.y = 0
@@ -1185,14 +1206,26 @@ local function get_item_bg_color(self, item)
 end
 
 
+---Render the message to be shown on the StatusView..
+---@param self core.statusview
+---@return core.statusview.styledtext
+local function get_rendered_message(self)
+  return {
+    self.message.icon_color, style.icon_font, self.message.icon,
+    style.dim, style.font, StatusView.separator2, style.text, self.message.text
+  }
+end
+
+
 function StatusView:draw()
   if not self.visible and self.size.y <= 0 then return end
 
   self:draw_background(style.background2)
 
   if self.message and system.get_time() <= self.message_timeout then
-    self:draw_items(self.message, false, 0, self.size.y)
+    self:draw_items(get_rendered_message(self), false, 0, self.size.y)
   else
+    if self.message then self.message = nil end
     if self.tooltip_mode then
       self:draw_items(self.tooltip)
     end
