@@ -442,9 +442,6 @@ function TreeView:draw()
   self:draw_background(style.background2)
   local _y, _h = self.position.y, self.size.y
 
-  local doc = core.active_view.doc
-  local active_filename = doc and core.project_absolute_path(doc.abs_filename or "")
-
   local sw, ox = 0, math.abs(self:get_content_offset())
   for item, x,y,w,h in self:each_item() do
     if y + h >= _y and y < _y + _h then
@@ -887,8 +884,16 @@ command.add(
   ["treeview:new-file"] = function(item)
     local text, path
     if not is_project_folder(item) then
-      text = item.filename .. PATHSEP
       path = common.dirname(item.abs_filename)
+      if item.type == "dir" then
+        text = item.filename .. PATHSEP
+      elseif item.type == "file" then
+        local parent_dir = common.dirname(
+          item.project:normalize_path(item.abs_filename)
+        )
+        text = parent_dir and parent_dir .. PATHSEP
+        path = common.dirname(path)
+      end
     else
       path = item.project.path
     end
@@ -903,7 +908,7 @@ command.add(
         core.log("Created %s", doc_filename)
       end,
       suggest = function(text)
-        return common.path_suggest(text, item.abs_filename)
+        return common.path_suggest(text, path)
       end
     })
   end,
@@ -911,8 +916,16 @@ command.add(
   ["treeview:new-folder"] = function(item)
     local text, path
     if not is_project_folder(item) then
-      text = item.filename .. PATHSEP
       path = common.dirname(item.abs_filename)
+      if item.type == "dir" then
+        text = item.filename .. PATHSEP
+      elseif item.type == "file" then
+        local parent_dir = common.dirname(
+          item.project:normalize_path(item.abs_filename)
+        )
+        text = parent_dir and parent_dir .. PATHSEP
+        path = common.dirname(path)
+      end
     else
       path = item.project.path
     end
@@ -924,7 +937,7 @@ command.add(
         core.log("Created %s", dir_path)
       end,
       suggest = function(text)
-        return common.path_suggest(text, item.abs_filename)
+        return common.path_suggest(text, path)
       end
     })
   end,
@@ -1048,6 +1061,18 @@ config.plugins.treeview.config_spec = {
       view.visible = not value
     end
   },
+  {
+    label = "Show Toolbar",
+    description = "Show or hide the treeview toolbar.",
+    path = "show_toolbar",
+    type = "toggle",
+    default = true,
+    on_apply = function (value)
+    	if toolbar_view.visible ~= value then
+    	  toolbar_view:toggle_visible()
+    	end
+    end
+  },
   {
     label = "Show Hidden",
     description = "Show hidden files and directories.",
